@@ -4,7 +4,9 @@ from django_otp import user_has_device
 from django_otp.conf import settings
 
 
-def otp_required(view=None, redirect_field_name='next', login_url=None, if_configured=False):
+def otp_required(
+    view=None, redirect_field_name='next', login_url=None, if_configured=False
+):
     """
     Similar to :func:`~django.contrib.auth.decorators.login_required`, but
     requires the user to be :term:`verified`. By default, this redirects users
@@ -18,8 +20,12 @@ def otp_required(view=None, redirect_field_name='next', login_url=None, if_confi
         login_url = settings.OTP_LOGIN_URL
 
     def test(user):
-        return user.is_verified() or (if_configured and user.is_authenticated and not user_has_device(user))
+        return user.is_verified() or (
+            if_configured and user.is_authenticated and not user_has_device(user)
+        )
 
-    decorator = user_passes_test(test, login_url=login_url, redirect_field_name=redirect_field_name)
+    decorator = user_passes_test(
+        test, login_url=login_url, redirect_field_name=redirect_field_name
+    )
 
     return decorator if (view is None) else decorator(view)
